@@ -27,10 +27,15 @@ mergeMeshes <- function(...)
     args <- list(...)
     if (length(args) == 1 && !inherits(args[[1]],"mesh3d"))
         args <- unlist(args, recursive = FALSE)
-
+    #print(class(args[[1]]))
     argc <- length(args)
-        if (argc < 2)
-            stop("at least two arguments needed")
+    if (argc < 2) {
+        if (inherits(args[[1]],"mesh3d")) {
+            message("only one arguments provided: nothing to be done")
+            return(args[[1]])
+        }
+    }
+    
     outmesh <- args[[1]]
     if (dim(outmesh$vb)[1] == 3)
         outmesh$vb <- rbind(outmesh$vb, 1)
@@ -72,10 +77,11 @@ mergeMeshes <- function(...)
 
         ## handle colors
         #tmpmesh$material$color <- matrix(tmpmesh$material$color,3,nittmp)
-        if (!is.null(tmpmesh$material$color) && is.null(outmesh$material$color) && !is.null(outmesh$it)) {
+        if (!is.null(tmpmesh$material$color) && is.null(outmesh$material$color)) {
             outmesh$material$color <- rep("#FFFFFF", nvbout)
-        } else if (is.null(tmpmesh$material$color) && !is.null(tmpmesh$it) && !is.null(outmesh$material$color))
-            tmpmesh$material$color <- matrix("#FFFFFF", 3, nvbtmp)
+        } else if (is.null(tmpmesh$material$color) && !is.null(outmesh$material$color))
+            tmpmesh$material$color <- rep("#FFFFFF", nvbtmp)
+        
         outmesh$material$color <- c(outmesh$material$color, tmpmesh$material$color)
     }
     return(outmesh)
