@@ -19,6 +19,7 @@
 #' to file - can slow things down for very large meshes.
 #' @author Stefan Schlager
 #' @note meshes containing quadrangular faces will be converted to triangular meshes by splitting the faces.
+#' Additionally, mesh2obj is now simply a wrapper of \code{Rvcg::vcgObjWrite}.
 #' @seealso \code{\link{ply2mesh}, \link{quad2trimesh} }
 #' 
 #' @examples
@@ -36,6 +37,7 @@
 #' shade3d(cube,col=3) ## view the green cube
 #' }
 #' mesh2ply(cube,filename="cube") # write cube to a file called cube.ply
+#' unlink("cube.ply")
 #' @rdname mesh2ply
 #' @export
 mesh2ply <- function(x, filename=dataname, col=NULL, writeNormals=FALSE)
@@ -69,11 +71,12 @@ mesh2ply <- function(x, filename=dataname, col=NULL, writeNormals=FALSE)
     texfile <- x$TextureFile
 
     if (is.null(col) && !is.null(x$material$color)) {
-        col=rep("#FFFFFF",vn)
-        tmp1 <- data.frame(it=as.vector(x$it))
-        tmp1$rgb <- as.vector(x$material$color)
-        tmp1 <- unique(tmp1)
-        col[tmp1$it] <- tmp1$rgb
+        ## col=rep("#FFFFFF",vn)
+        ## tmp1 <- data.frame(it=as.vector(x$it))
+        ## tmp1$rgb <- as.vector(x$material$color)
+        ## tmp1 <- unique(tmp1)
+        ## col[tmp1$it] <- tmp1$rgb
+        col <- x$material$color
     }
     if (!writeNormals)
         x$normals <- NULL
@@ -114,11 +117,8 @@ mesh2ply <- function(x, filename=dataname, col=NULL, writeNormals=FALSE)
 ### write vertices and vertex normals ###
     vert.all <- data.frame(t(vert.all))
     if (!is.null(col)) {
-        if (is.vector(col)) {
-            colout <- t(col2rgb(col))
-        } else
-            colout <- matrix(col2rgb(col),vn,3,byrow=T)
-        
+        colout <- t(col2rgb(col))
+             
         vert.all <- cbind(vert.all,colout)
     }
     
