@@ -25,6 +25,8 @@
 #' 
 #' mesh2obj(shortnose.mesh)
 #' mesh2 <- obj2mesh("shortnose.mesh.obj")
+#' ## cleanup
+#' unlink(c("shortnose.mesh.obj","shortnose.mesh.ply"))
 #' @rdname ply2mesh
 #' @export
 ply2mesh <- function (filename, adnormals = TRUE,readnormals=FALSE,readcol=FALSE, silent=FALSE)
@@ -91,7 +93,7 @@ ply2mesh <- function (filename, adnormals = TRUE,readnormals=FALSE,readcol=FALSE
                     x <- colmat[x]
                     return(x)
                 }
-            material$color <- matrix(colfun(face),dim(face))
+            material$color <- colmat
         }
         mesh <- list(vb = rbind(t(vert), 1), it = face, primitivetype = "triangle", material = material,normals = vert.n)      
         class(mesh) <- c("mesh3d", "shape3d")
