@@ -5,5 +5,5 @@ test_that("CVA behaves", {
     facto <- iris[,5]
     cva.1 <- CVA(vari, groups=facto)
     CVA.baseline=readRDS("testdata/CVA.rds")
-    expect_equal(abs(cva.1$CV),abs(CVA.baseline$CV),tol=0.001)
+    expect_equal(abs(cva.1$CV),abs(CVA.baseline$CV),tol=0.001,check.attributes=FALSE)
 })
